/**
 * Utility to estimate the reading time, taking readability of the document and
 * a target age group into account.
 *
 * *   [1] For more info on US education/grade levels, see:
 *     <https://en.wikipedia.org/wiki/Educational_stage#United_States>.
 * *   [2] For the wpm of people reading English, see:
 *     <https://en.wikipedia.org/wiki/Words_per_minute#Reading_and_comprehension>
 * *   [3] For information on reading rate, including how grade levels affect
 *     them, see: <https://en.wikipedia.org/wiki/Reading#Reading_rate>.
 *
 * And some more background info/history and a few insight on where this comes
 * from, see: <https://martech.org/estimated-reading-times-increase-engagement/>.
 *
 * @param {Node} tree
 *   Content to estimate.
 * @param {Options} [options]
 *   Configuration.
 * @returns {number}
 *   Estimated reading time in minutes.
 */
export function readingTime(tree: Node, options?: Options | undefined): number
export type Root = import('hast').Root
export type Content = import('hast').Content
export type Node = Root | Content
export type Options = {
  /**
   * Target age group.
   * This is the age your target audience was still in school.
   * Set it to 18 if you expect all readers to have finished high school,
   * 21 if you expect your readers to all be college graduates, etc.
   */
  age?: number | undefined
}
